@@ -4,7 +4,7 @@ import json
 
 def myconverter(o):
     if isinstance(o, datetime.datetime):
-        return o.__str__().replace(" ", "T")
+        return o.isoformat()
 
 
 def apply(log, output_path, parameters=None):
